Data science gear (ds-gear) is a Python API for advanced machine learning algorithms built on top of sklearn, tensorflow and keras and is distributed under the Mit license.
### Description
1. RNN_MTO_Classifier:  
Text scoring RNN based on Many-to-One architecture.  
Example applications include sentiment analysis, review scoring  
2. RNN_MTM_Classifier:  
Text classification RNN based on Many-to-Many architecture.  
Example applications include Named entity recognition, machine translation  
### Installation
## Depenencies
- Python (> 3.6)
- Numpy
- Pandas
- sklearn
- Matplotlib
- Pylint
- Doxypypy
- Nltk (==3.5)
- keras
- tensorflow
- keras-contrib (need to be installed prior to this package)
## User installation
1. keras-contrib installation (please refer to git repo @ https://github.com/keras-team/keras-contrib)
2. package installation: `pip install ds-gear`

### Source code
You can check the latest sources with the command:  
`git clone https://github.com/AI-Companion/ds-gear.git`



